@@ -47,5 +47,36 @@ summary.PDFe <- function(object, ...){
                 length(which(estimate$lagrange != 0))), quote = FALSE)
   
   return(invisible(object))
+}
+
+
+summary.mvPDFe <- function(object, ...){
+  estimate = object 
   
-}
\ No newline at end of file
+  print(sprintf("Multivariate Probability Density"), quote = FALSE)
+  print("", quote = FALSE)
+  print(sprintf("   number of variables:  %d", 
+                estimate$variableLength), quote = FALSE)
+  print(sprintf("   sample length:        %d", 
+                estimate$sampleLength), quote = FALSE)
+  print(sprintf("   grid resolution:      %d", 
+                estimate$resolution), quote = FALSE)
+  
+  print(sprintf("   minimum density:      %0.4f", 
+                min(estimate$pdf)), quote = FALSE)
+  print(sprintf("   maximum density:      %0.4f", 
+                max(estimate$pdf)), quote = FALSE)
+  print("", quote = FALSE)
+  
+  print(sprintf("Estimated Ranges"), quote = FALSE)
+  print("", quote = FALSE)
+  i = 1;
+  for (v in 1:estimate$variableLength) {
+    temp = estimate$x[i:(i + estimate$resolution - 1)];
+    print(sprintf("  variable %d:  [%0.4f  %0.4f]", v, min(temp), max(temp)), quote = FALSE)
+    i = i + estimate$resolution
+  }
+  
+  return(invisible(object))
+}
+  
\ No newline at end of file
